fintorch.datasets package
=========================

Submodules
----------

fintorch.datasets.elliptic module
---------------------------------

.. automodule:: fintorch.datasets.elliptic
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.ellipticpp module
-----------------------------------

.. automodule:: fintorch.datasets.ellipticpp
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fintorch.datasets
   :members:
   :undoc-members:
   :show-inheritance:
